@@ -6,14 +6,13 @@
 # @argument y position
 # @keywords internal
 #X annotate("text", x = 0, y = 0, label = "title")
-annotate <- function(geom, x, y, xmin = NULL, xmax = NULL, ymin = NULL, ymax = NULL, ...) {
+annotate <- function(geom, x = NULL, y = NULL, xmin = NULL, xmax = NULL, ymin = NULL, ymax = NULL, ...) {
   
   layer_data <- compact(list(
     x = x, xmin = xmin, xmax = xmax, 
     y = y, ymin = ymin, ymax = ymax
   ))
   
-  
   layer(
     geom = geom, geom_params = list(...), 
     stat = "identity", 
