@@ -5,8 +5,11 @@ GeomRibbon <- proto(Geom, {
   guide_geom <- function(.) "polygon"
 
 
-  draw <- function(., data, scales, coordinates, ...) {
-    data <- data[complete.cases(data[, c("x","ymin","ymax")]), ]
+  draw <- function(., data, scales, coordinates, na.rm = FALSE, ...) {
+    data <- remove_missing(data, na.rm, 
+      c("x","ymin","ymax"), name = "geom_ribbon")
+    data <- data[order(data$group, data$x), ]
+    
     tb <- with(data,
       coordinates$munch(data.frame(x=c(x, rev(x)), y=c(ymax, rev(ymin))), scales)
     )
