@@ -56,6 +56,21 @@ Layer <- proto(expr = {
       geom_params <- rename_aes(geom_params)
     }
     
+    if (!is.null(geom_params)) {
+      set_aesthetics <- geom_params[intersect(names(geom_params), .all_aesthetics)]
+      # Check that all set aesthetics have length 1
+      if (length(set_aesthetics) > 0) {
+        lengths <- sapply(set_aesthetics, length)
+        if (any(lengths > 1)) {
+          stop("When _setting_ aesthetics, they may only take one value. ", 
+            "Problems: ",
+            paste(names(set_aesthetics)[lengths > 1], collapse = ","), 
+            call. = FALSE)
+        }
+        
+      }
+    }
+    
     proto(., 
       geom=geom, geom_params=geom_params, 
       stat=stat, stat_params=stat_params, 
@@ -69,10 +84,12 @@ Layer <- proto(expr = {
   clone <- function(.) as.proto(.$as.list(all.names=TRUE))
   
   use_defaults <- function(., data) {
-    df <- aesdefaults(data, .$geom$default_aes(), compact(.$mapping))
+    mapped_vars <- .$mapping[!sapply(.$mapping, is.character)]
+    df <- aesdefaults(data, .$geom$default_aes(), mapped_vars)
     
     # Override mappings with parameters
     gp <- intersect(c(names(df), .$geom$required_aes), names(.$geom_params))
+
     if (length(.$geom_params[gp])) 
       gp <- gp[sapply(.$geom_params[gp], is.atomic)]
     df[gp] <- .$geom_params[gp]
