@@ -73,7 +73,12 @@ StatDensity <- proto(Stat, {
     m + stat_bin()
     
     # Make a volcano plot
-    ggplot(diamonds, aes(x = price)) + geom_density(aes(min = -..density.., adjust= 0.5),fill="grey50", colour=NA) + facet_grid(. ~ cut) + coord_flip() 
+    ggplot(diamonds, aes(x = price)) + 
+      stat_density(aes(ymax = ..density..,  ymin = -..density..), 
+        fill = "grey50", colour = "grey50", 
+        geom = "ribbon", position = "identity") + 
+      facet_grid(. ~ cut) + 
+      coord_flip()
 
     # Stacked density plots
     # If you want to create a stacked density plot, you need to use
