@@ -7,7 +7,7 @@
 # 
 # One way to think about a parallel coordinates plot, is as plotting 
 # the data after it has transformation been transformed to gain a new
-# variable.  This function does this using \\code{\\link[reshape]{melt}}.
+# variable.  This function does this using \code{\link[reshape]{melt}}.
 # 
 # This gives us enormous flexibility as we have separated out the 
 # type of drawing (lines by tradition) and can now use any of the existing
@@ -30,7 +30,7 @@
 #X ggpcp(mtcars, vars=names(mtcars)[3:6], formula= . ~cyl, scale="I") + geom_line()
 #X ggpcp(mtcars, scale="I") + geom_boxplot(aes(group=variable))
 #X ggpcp(mtcars, vars=names(mtcars[2:6])) + geom_line()
-#X p <- ggpcp(mtcars, vars=names(mtcars[2:6]), formula=.~vs)
+#X p <- ggpcp(mtcars, vars=names(mtcars[2:6]))
 #X p + geom_line()
 #X p + geom_line(aes(colour=mpg)) 
 ggpcp <- function(data, vars=names(data), scale="range", ...) {
@@ -41,8 +41,7 @@ ggpcp <- function(data, vars=names(data), scale="range", ...) {
   data$ROWID <- 1:nrow(data)
   molten <- melt(data, m=vars)
 
-  p <- ggplot(molten, aes_string(x="variable", y="value", group="ROWID"), ...)
-  p + scale_x_discrete()
+  ggplot(molten, aes_string(x = "variable", y = "value", group = "ROWID"), ...)
 }
 
 # Fluctuation plot
