@@ -66,7 +66,7 @@ Trans <- proto(TopLevel, {
 
 PowerTrans <- proto(Trans, {
   new <- function(., exponent) {
-    .$proto(name = paste("pow", exponent, sep=""), p = exponent)
+    .$proto(objname = paste("pow", exponent, sep=""), p = exponent)
   }
   transform <- function(., values) {
     (values^.$p - 1) / .$p * sign(values - 1)
@@ -79,7 +79,7 @@ PowerTrans <- proto(Trans, {
 
 ProbabilityTrans <- proto(Trans, {
   new <- function(., family) {
-    .$proto(name=family, family = family)
+    .$proto(objname=family, family = family)
   }
   transform <- function(., values) {
     if (is.null(values)) return()
@@ -96,24 +96,19 @@ TransAsn <- Trans$new(
   function(x) 2 * asin(sqrt(x)), 
   function(x) sin(x / 2)^2
 )
-
-TransAtanh <- Trans$new(
-  "atanh", 
-  "tanh", 
-  "force"
-)
-  
+TransAtanh <- Trans$new("atanh", "atanh", "tanh", "force")
 TransExp <- Trans$new("exp", "exp", "log", function(x) bquote(log(.(x))))
 TransIdentity <- Trans$new("identity", "force", "force", "force")
 TransInverse <- Trans$new("inverse", function(x) 1/x, function(x) 1/x,  function(x) bquote(phantom()^1 / phantom()[.(x)]))
 TransLog <- Trans$new("log", "log", "exp", function(x) bquote(e^.(x)))
 TransLog10 <- Trans$new("log10", "log10", function(x) 10^x, function(x) bquote(10^.(x)))
 TransLog2 <- Trans$new("log2", "log2", function(x) 2^x, function(x) bquote(2^.(x)))
-TransLogit <- ProbabilityTrans$new("logis")
 TransPow10 <- Trans$new("pow10",function(x) 10^x, "log10", function(x) log10(x))
-TransProbit <- ProbabilityTrans$new("norm")
 TransReverse <- Trans$new("reverse", function(x) -x, function(x) -x, function(x) bquote(.(-x)))
 TransSqrt <- Trans$new("sqrt", "sqrt", function(x) x^2, function(x) x^2)
 
 TransDate <- Trans$new("date", "as.numeric", "to_date")
 TransDatetime <- Trans$new("datetime", "as.numeric", "to_time")
+
+TransLogit <- ProbabilityTrans$new("logis")
+TransProbit <- ProbabilityTrans$new("norm")
