@@ -2,7 +2,7 @@
 # Wrapper for colorRamp that deals with missing values and alpha
 # 
 # @keyword internal
-nice_ramp <- function(ramp, x, alpha) {
+nice_ramp <- function(ramp, x, alpha = 1) {
   cols <- ramp(x)
   missing <- !complete.cases(x)
   cols[missing, ] <- 0
@@ -21,7 +21,20 @@ nice_ramp <- function(ramp, x, alpha) {
 # @keyword internal 
 alpha <- function(colour, alpha) {
   col <- col2rgb(colour, TRUE) / 255
-  col[4, ] <- rep(alpha, length.out = length(colour))
+  
+  if (length(colour) != length(alpha)) {
+    if (length(colour) > 1 && length(alpha) > 1) {
+      stop("Only one of colour and alpha can be vectorised")
+    }
+    
+    if (length(colour) > 1) {
+      alpha <- rep(alpha, length.out = length(colour))    
+    } else if (length(alpha) > 1) {
+      col <- col[, rep(1, length(alpha)), drop = FALSE]
+    }
+  }
+  # Only set if colour is opaque
+  col[4, ] <- ifelse(col[4, ] == 1, alpha, col[4, ])
 
   new_col <- rgb(col[1,], col[2,], col[3,], col[4,])
   new_col[is.na(colour)] <- NA  
