@@ -44,7 +44,7 @@ position_fill <- PositionFill$build_accessor()
 position_identity <- PositionIdentity$build_accessor()
 position_jitter <- PositionJitter$build_accessor()
 position_stack <- PositionStack$build_accessor()
-scale_alpha <- ScaleAlpha$build_accessor()
+scale_alpha_continuous <- ScaleAlphaContinuous$build_accessor()
 scale_area <- ScaleArea$build_accessor()
 scale_colour <- ScaleColour$build_accessor()
 scale_colour_brewer <- ScaleBrewer$build_accessor(list(variable = "\"colour\""))
@@ -64,13 +64,13 @@ scale_fill_grey <- ScaleGrey$build_accessor(list(variable = "\"fill\""))
 scale_fill_hue <- ScaleHue$build_accessor(list(variable = "\"fill\""))
 scale_fill_identity <- ScaleIdentity$build_accessor(list(variable = "\"fill\""))
 scale_fill_manual <- ScaleManual$build_accessor(list(variable = "\"fill\""))
-scale_linetype <- ScaleLinetype$build_accessor()
+scale_linetype_discrete <- ScaleLinetypeDiscrete$build_accessor()
 scale_linetype_identity <- ScaleIdentity$build_accessor(list(variable = "\"linetype\""))
 scale_linetype_manual <- ScaleManual$build_accessor(list(variable = "\"linetype\""))
-scale_shape <- ScaleShape$build_accessor()
+scale_shape_discrete <- ScaleShapeDiscrete$build_accessor()
 scale_shape_identity <- ScaleIdentity$build_accessor(list(variable = "\"shape\""))
 scale_shape_manual <- ScaleManual$build_accessor(list(variable = "\"shape\""))
-scale_size <- ScaleSize$build_accessor()
+scale_size_continuous <- ScaleSizeContinuous$build_accessor()
 scale_size_discrete <- ScaleSizeDiscrete$build_accessor()
 scale_size_identity <- ScaleIdentity$build_accessor(list(variable = "\"size\""))
 scale_size_manual <- ScaleManual$build_accessor(list(variable = "\"size\""))
